Learn R Programming

knitxl (version 0.1.0)

sew.knitxl_output_text: Extend knitr::sew() generic to write text, vectors and data table to the output .xlsx file.

Description

These functions are called within knitr::knit() to write either text vector or a table into the output .xlsx file produced by knitxl().

Usage

# S3 method for knitxl_output_text
sew(x, options, ...)

# S3 method for knitxl_output_vector sew(x, options, ...)

# S3 method for knitxl_output_data_frame sew(x, options, ...)

Value

Invisibly returns NULL.

Arguments

x

Output from evaluate::evaluate().

options

A list of chunk options used to control output.

...

Other arguments to pass to methods.